==> shinyutils-9.2.0.tar.gz: shinyutils-9.2.0/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file. See [standard-version](https://github.com/conventional-changelog/standard-version) for commit guidelines.

## [9.2.0](https://github.com/jayanthkoushik/shinyutils/compare/v9.1.0...v9.2.0) (2021-11-16)


### Features

* allow specifying palette size in matwrap ([b53e72b](https://github.com/jayanthkoushik/shinyutils/commit/b53e72bfed3b54cf80783f8e02042c6a4bfa9ca0))


### Bug Fixes

* update corgy to 2.0 for SubClassType update ([7a9e5b7](https://github.com/jayanthkoushik/shinyutils/commit/7a9e5b7b33253fc29db49d6cdf703543f258cbf1))

## [9.1.0](https://github.com/jayanthkoushik/shinyutils/compare/v9.0.0...v9.1.0) (2021-10-28)


### Features

* allow specifying custom backend directly in MatWrap ([cf8948d](https://github.com/jayanthkoushik/shinyutils/commit/cf8948d5969b1f1ebdf3ac2e04240ad00beb3b1c))


### Bug Fixes

* use actual colorblind cud palette ([8f34e19](https://github.com/jayanthkoushik/shinyutils/commit/8f34e19a272b1768a6116517982a3c9334d8d8c4))

## [9.0.0](https://github.com/jayanthkoushik/shinyutils/compare/v8.0.0...v9.0.0) (2021-10-21)


### ⚠ BREAKING CHANGES

* update dependencies

### Features

* add sh module ([43971aa](https://github.com/jayanthkoushik/shinyutils/commit/43971aad310b60544a38e07a998c6ac862ecb4f3))
* make matwrap.Plot save_file argument optional ([8f3da34](https://github.com/jayanthkoushik/shinyutils/commit/8f3da344e991f1d152210b7b6bc81ffe6f445a6b))


### build

* update dependencies ([0456a43](https://github.com/jayanthkoushik/shinyutils/commit/0456a43be86fc43c45dca8ceb72b72de5dd77bef))

==> shinyutils-9.2.1.tar.gz: shinyutils-9.2.1/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file. See [standard-version](https://github.com/conventional-changelog/standard-version) for commit guidelines.

### [9.2.1](https://github.com/jayanthkoushik/shinyutils/compare/v9.2.0...v9.2.1) (2021-11-16)


### Bug Fixes

* update corgy to 2.0.1 ([b577e3b](https://github.com/jayanthkoushik/shinyutils/commit/b577e3b6adb00bd21aea5496dd62575909c727b7))

## [9.2.0](https://github.com/jayanthkoushik/shinyutils/compare/v9.1.0...v9.2.0) (2021-11-16)


### Features

* allow specifying palette size in matwrap ([b53e72b](https://github.com/jayanthkoushik/shinyutils/commit/b53e72bfed3b54cf80783f8e02042c6a4bfa9ca0))


### Bug Fixes

* update corgy to 2.0 for SubClassType update ([7a9e5b7](https://github.com/jayanthkoushik/shinyutils/commit/7a9e5b7b33253fc29db49d6cdf703543f258cbf1))

## [9.1.0](https://github.com/jayanthkoushik/shinyutils/compare/v9.0.0...v9.1.0) (2021-10-28)


### Features

* allow specifying custom backend directly in MatWrap ([cf8948d](https://github.com/jayanthkoushik/shinyutils/commit/cf8948d5969b1f1ebdf3ac2e04240ad00beb3b1c))


### Bug Fixes

* use actual colorblind cud palette ([8f34e19](https://github.com/jayanthkoushik/shinyutils/commit/8f34e19a272b1768a6116517982a3c9334d8d8c4))

## [9.0.0](https://github.com/jayanthkoushik/shinyutils/compare/v8.0.0...v9.0.0) (2021-10-21)


### ⚠ BREAKING CHANGES

* update dependencies

### Features

* add sh module ([43971aa](https://github.com/jayanthkoushik/shinyutils/commit/43971aad310b60544a38e07a998c6ac862ecb4f3))
* make matwrap.Plot save_file argument optional ([8f3da34](https://github.com/jayanthkoushik/shinyutils/commit/8f3da344e991f1d152210b7b6bc81ffe6f445a6b))


### build

* update dependencies ([0456a43](https://github.com/jayanthkoushik/shinyutils/commit/0456a43be86fc43c45dca8ceb72b72de5dd77bef))
